@@ -2,14 +2,14 @@ use super::command::Command;
 use crate::cli::Cli;
 use crate::config::FnmConfig;
 use crate::shell::{infer_shell, AVAILABLE_SHELLS};
-use snafu::{OptionExt, Snafu};
-use structopt::clap::Shell;
-use structopt::StructOpt;
+use clap::{IntoApp, Parser};
+use clap_complete::{Generator, Shell};
+use thiserror::Error;
 
-#[derive(StructOpt, Debug)]
+#[derive(Parser, Debug)]
 pub struct Completions {
     /// The shell syntax to use. Infers when missing.
-    #[structopt(long, possible_values = &Shell::variants())]
+    #[clap(long)]
     shell: Option<Shell>,
 }
 
@@ -21,21 +21,22 @@ impl Command for Completions {
         let shell = self
             .shell
             .or_else(|| infer_shell().map(Into::into))
-            .context(CantInferShell)?;
-        Cli::clap().gen_completions_to(env!("CARGO_PKG_NAME"), shell, &mut stdio);
+            .ok_or(Error::CantInferShell)?;
+        let app = Cli::command();
+        shell.generate(&app, &mut stdio);
         Ok(())
     }
 }
 
-#[derive(Snafu, Debug)]
+#[derive(Error, Debug)]
 pub enum Error {
-    #[snafu(display(
+    #[error(
         "{}\n{}\n{}\n{}",
         "Can't infer shell!",
         "fnm can't infer your shell based on the process tree.",
         "Maybe it is unsupported? we support the following shells:",
         shells_as_string()
-    ))]
+    )]
     CantInferShell,
 }
 
