@@ -1,16 +1,15 @@
 use super::command::Command;
 use crate::config::FnmConfig;
 use crate::current_version::{current_version, Error};
-use structopt::StructOpt;
 
-#[derive(StructOpt, Debug)]
+#[derive(clap::Parser, Debug)]
 pub struct Current {}
 
 impl Command for Current {
     type Error = Error;
 
     fn apply(self, config: &FnmConfig) -> Result<(), Self::Error> {
-        let version_string = match current_version(&config)? {
+        let version_string = match current_version(config)? {
             Some(ver) => ver.v_str(),
             None => "none".into(),
         };
