@@ -1,3 +1,11 @@
+#![warn(rust_2018_idioms, clippy::all, clippy::pedantic)]
+#![allow(
+    clippy::enum_variant_names,
+    clippy::large_enum_variant,
+    clippy::module_name_repetitions,
+    clippy::similar_names
+)]
+
 mod alias;
 mod arch;
 mod archive;
@@ -9,6 +17,7 @@ mod current_version;
 mod directory_portal;
 mod downloader;
 mod fs;
+mod http;
 mod installed_versions;
 mod lts;
 mod path_ext;
@@ -19,10 +28,13 @@ mod system_version;
 mod user_version;
 mod user_version_reader;
 mod version;
+mod version_file_strategy;
 mod version_files;
 
 #[macro_use]
 mod log_level;
+mod default_version;
+mod directories;
 
 fn main() {
     env_logger::init();
